==> nextcloud-26.0.7p0.tgz: nextcloud/apps/twofactor_totp/l10n/de.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Du hast TOTP Zwei-Faktor-Authentifizierung für dein Konto aktiviert",
    "You disabled TOTP two-factor authentication for your account" : "Du hast TOTP Zwei-Faktor-Authentifizierung für dein Konto deaktiviert",
    "TOTP two-factor authentication disabled by an admin" : "TOTP Zwei-Faktor-Authentifizierung wurde von einem Administrator deaktiviert",
    "TOTP (Authenticator app)" : "TOTP (App zur Authentifizierung)",
    "Authenticate with a TOTP app" : "Mit einer TOTP-App authentifizieren",
    "Two-Factor TOTP Provider" : "Zwei-Faktor TOTP-Anbieter",
    "TOTP two-factor provider" : "TOTP-Zwei-Faktor-Anbieter",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Ein Zwei-Faktor-Anbieter für TOTP (RFC 6238)",
    "Enable TOTP" : "TOTP aktivieren",
    "Could not enable TOTP" : "TOTP konnte nicht aktiviert werden",
    "Could not verify your key. Please try again" : "Dein Schlüssel konnte nicht überprüft werden. Bitte erneut versuchen.",
    "Your new TOTP secret is:" : "Dein neuer TOTP-Schlüssel ist:",
    "For quick setup, scan this QR code with your TOTP app:" : "Für eine schnelle Einrichtung diesen QR-Code mit der TOTP-App scannen:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Nachdem du die App konfiguriert hast, gebe unten einen Testcode ein, um sicherzustellen, dass alles funktioniert:",
    "Authentication code" : "Authentifizierungscode",
    "Verify" : "Überprüfen",
    "Get the authentication code from the two-factor authentication app on your device." : "Erhalte den Authentifizierungscode von der Zweifaktorauthentifizierung-App auf deinem Gerät.",
    "Submit" : "Übermitteln"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/twofactor_totp/l10n/de.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Du hast TOTP Zwei-Faktor-Authentifizierung für dein Konto aktiviert",
    "You disabled TOTP two-factor authentication for your account" : "Du hast TOTP Zwei-Faktor-Authentifizierung für dein Konto deaktiviert",
    "TOTP two-factor authentication disabled by the administration" : "TOTP-Zwei-Faktor-Authentifizierung von der Administration deaktiviert",
    "TOTP (Authenticator app)" : "TOTP (App zur Authentifizierung)",
    "Authenticate with a TOTP app" : "Mit einer TOTP-App authentifizieren",
    "Two-Factor TOTP Provider" : "Zwei-Faktor TOTP-Anbieter",
    "Two-factor TOTP provider" : "Zwei-Faktor TOTP-Anbieter",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Ein Zwei-Faktor-Authentifizierungsanbieter für TOTP (RFC 6238)",
    "Enable TOTP" : "TOTP aktivieren",
    "Could not enable TOTP" : "TOTP konnte nicht aktiviert werden",
    "Could not verify your key. Please try again" : "Dein Schlüssel konnte nicht überprüft werden. Bitte erneut versuchen.",
    "Your new TOTP secret is:" : "Dein neuer TOTP-Schlüssel ist:",
    "For quick setup, scan this QR code with your TOTP app:" : "Für eine schnelle Einrichtung diesen QR-Code mit der TOTP-App scannen:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Nachdem du die App konfiguriert hast, gib unten einen Testcode ein, um sicherzustellen, dass alles funktioniert:",
    "Authentication code" : "Authentifizierungscode",
    "Verify" : "Überprüfen",
    "Get the authentication code from the two-factor authentication app on your device." : "Erhalte den Authentifizierungscode von der Zweifaktorauthentifizierung-App auf deinem Gerät.",
    "Submit" : "Übermitteln",
    "TOTP two-factor authentication disabled by an admin" : "TOTP Zwei-Faktor-Authentifizierung wurde von einem Administrator deaktiviert",
    "TOTP two-factor provider" : "TOTP-Zwei-Faktor-Anbieter",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Ein Zwei-Faktor-Anbieter für TOTP (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");
